cmd

package
v0.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Copyright © 2022 Yoan BERNABEU <yoan.bernabeu@gmail.com>

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type JelasticResponse added in v0.2.0

type JelasticResponse struct {
	Result int         `json:"result"`
	Error  string      `json:"error"`
	Raw    interface{} `json:"raw"`
	Source string      `json:"source"`
}

JelasticResponse represents the structure of a Jelastic API response

Jump to